/*
 * Removal of this header is illegal.
 * Written by Scott Auge scott_auge@yahoo.com sauge@amduus.com
 * Copyright (c) 2002 Amduus Information Works, Inc.  www.amduus.com
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes software developed by Amduus Information Works
 *      Inc. and its contributors.
 * 4. Neither the name of Amduus Information Works, Inc. nor the names of 
 *    its contributors may be used to endorse or promote products derived 
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY AMDUUS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AMDUUS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 */


DEF INPUT PARAMETER cSessionID AS CHARACTER NO-UNDO.

DEF VAR cCommand AS CHARACTER NO-UNDO.
DEF VAR iCurWord AS INTEGER NO-UNDO.
DEF VAR iMaxWord AS INTEGER NO-UNDO.

DEF VAR cVerb    AS CHARACTER NO-UNDO.
DEF VAR cError   AS CHARACTER NO-UNDO.

/* Figure out the verb routine that should work on the command */

DEF NEW SHARED TEMP-TABLE WordList
  FIELD Order AS INTEGER
  FIELD Word  AS CHARACTER
  FIELD WordType AS CHARACTER
  INDEX pukey IS PRIMARY Order.

/* First we break up the sentence presented to us by the user */
/* We remember the order for grammar later on.                */

FIND WebState NO-LOCK
WHERE WebState.SessionID = cSessionID
  AND WebState.Category = "FeedBack"
  AND WebState.Name = "Command"
NO-ERROR.

ASSIGN cCommand = WebState.Data.

DO iCurWord = 1 TO NUM-ENTRIES(cCommand, " "):

  CREATE WordList.

  ASSIGN 
  WordList.Order = iCurWord
  WordList.Word  = ENTRY (iCurWord, cCommand, " ").

END.

/* Determine the word types for each word given.              */

FOR EACH WordList:

  FIND WordType NO-LOCK
  WHERE WordType.Word = WordList.Word
  NO-ERROR.

  IF NOT AVAILABLE WordType THEN
    ASSIGN WordList.WordType = "_NULL".
  ELSE
    ASSIGN WordList.WordType = WordType.WordType.

END. /* FOR EACH WordList */

/* Next we eliminate those words that are of little interest to our grammar */
/* parser, that is articles, prepositions, etc.                             */
/* _NULL is a special word for this system.  It should not be in the uni-   */
/* verse of vocabulary for the user.                                        */

ASSIGN cVerb = "_NULL".

FOR EACH WordList:

  IF WordList.WordType = "ARTICLE" THEN DO:
    DELETE WordList.
    NEXT.
  END.
  IF WordList.WordType = "_NULL" THEN DO:
    DELETE WordList.
    NEXT.
  END.
  IF WordList.WordType = "PREPOSITION" THEN DO:
    DELETE WordList.
    NEXT.
  END.
  IF WordList.WordType = "VERB" THEN ASSIGN cVerb = WordList.Word.

END. /* FOR EACH WordList */

/* Now determine the grammar construct that is available in the phrase and */
/* determine if it is something we can work with.  We do this by iden-     */
/* tifying the verb and it's associated routine to handle that "action."   */

FIND Verb NO-LOCK
WHERE Verb.Word = cVerb
NO-ERROR.

IF AVAILABLE Verb THEN 
  RUN VALUE(Verb.Program) (INPUT cSessionID).
ELSE 
  RUN WriteState.p (INPUT cSessionID,
                    INPUT "FeedBack",
                    INPUT "Message",
                    INPUT "I don't understand you",
                    OUTPUT cError).






